@@ -70,7 +70,7 @@ char owner[121] = "";              /* Permanent botowner(s)        */
  */
 void rmspace(char *s)
 {
-  register char *p = NULL, *q = NULL;
+  char *p = NULL, *q = NULL;
 
   if (!s || !*s)
     return;
@@ -91,7 +91,7 @@ void rmspace(char *s)
  */
 memberlist *ismember(struct chanset_t *chan, char *nick)
 {
-  register memberlist *x;
+  memberlist *x;
 
   for (x = chan->channel.member; x && x->nick[0]; x = x->next)
     if (!rfc_casecmp(x->nick, nick))
@@ -103,7 +103,7 @@ memberlist *ismember(struct chanset_t *chan, char *nick)
  */
 struct chanset_t *findchan(const char *name)
 {
-  register struct chanset_t *chan;
+  struct chanset_t *chan;
 
   for (chan = chanset; chan; chan = chan->next)
     if (!rfc_casecmp(chan->name, name))
@@ -115,7 +115,7 @@ struct chanset_t *findchan(const char *name)
  */
 struct chanset_t *findchan_by_dname(const char *name)
 {
-  register struct chanset_t *chan;
+  struct chanset_t *chan;
 
   for (chan = chanset; chan; chan = chan->next)
     if (!rfc_casecmp(chan->dname, name))
@@ -134,10 +134,10 @@ struct chanset_t *findchan_by_dname(const char *name)
 struct userrec *check_chanlist(const char *host)
 {
   char *nick, *uhost, buf[UHOSTLEN];
-  register memberlist *m;
-  register struct chanset_t *chan;
+  memberlist *m;
+  struct chanset_t *chan;
 
-  strncpyz(buf, host, sizeof buf);
+  strlcpy(buf, host, sizeof buf);
   uhost = buf;
   nick = splitnick(&uhost);
   for (chan = chanset; chan; chan = chan->next)
@@ -151,8 +151,8 @@ struct userrec *check_chanlist(const char *host)
  */
 struct userrec *check_chanlist_hand(const char *hand)
 {
-  register struct chanset_t *chan;
-  register memberlist *m;
+  struct chanset_t *chan;
+  memberlist *m;
 
   for (chan = chanset; chan; chan = chan->next)
     for (m = chan->channel.member; m && m->nick[0]; m = m->next)
@@ -168,8 +168,8 @@ struct userrec *check_chanlist_hand(const char *hand)
  */
 void clear_chanlist(void)
 {
-  register memberlist *m;
-  register struct chanset_t *chan;
+  memberlist *m;
+  struct chanset_t *chan;
 
   for (chan = chanset; chan; chan = chan->next)
     for (m = chan->channel.member; m && m->nick[0]; m = m->next) {
@@ -185,8 +185,8 @@ void clear_chanlist(void)
  */
 void clear_chanlist_member(const char *nick)
 {
-  register memberlist *m;
-  register struct chanset_t *chan;
+  memberlist *m;
+  struct chanset_t *chan;
 
   for (chan = chanset; chan; chan = chan->next)
     for (m = chan->channel.member; m && m->nick[0]; m = m->next)
@@ -202,10 +202,10 @@ void clear_chanlist_member(const char *nick)
 void set_chanlist(const char *host, struct userrec *rec)
 {
   char *nick, *uhost, buf[UHOSTLEN];
-  register memberlist *m;
-  register struct chanset_t *chan;
+  memberlist *m;
+  struct chanset_t *chan;
 
-  strncpyz(buf, host, sizeof buf);
+  strlcpy(buf, host, sizeof buf);
   uhost = buf;
   nick = splitnick(&uhost);
   for (chan = chanset; chan; chan = chan->next)
@@ -218,8 +218,8 @@ void set_chanlist(const char *host, struct userrec *rec)
  */
 int expmem_chanprog()
 {
-  register int tot = 0;
-  register tcl_timer_t *t;
+  int tot = 0;
+  tcl_timer_t *t;
 
   for (t = timer; t; t = t->next)
     tot += sizeof(tcl_timer_t) + strlen(t->cmd) + 1;
@@ -272,7 +272,7 @@ void tell_verbose_uptime(int idx)
   if (backgrd)
     strcpy(s1, MISC_BACKGROUND);
   else {
-    if (term_z)
+    if (term_z >= 0)
       strcpy(s1, MISC_TERMMODE);
     else if (con_chan)
       strcpy(s1, MISC_STATMODE);
@@ -325,14 +325,14 @@ void tell_verbose_status(int idx)
   sprintf(&s[strlen(s)], "%02d:%02d", (int) hr, (int) min);
   s1[0] = 0;
   if (backgrd)
-    strncpyz(s1, MISC_BACKGROUND, sizeof s1);
+    strlcpy(s1, MISC_BACKGROUND, sizeof s1);
   else {
-    if (term_z)
-      strncpyz(s1, MISC_TERMMODE, sizeof s1);
+    if (term_z >= 0)
+      strlcpy(s1, MISC_TERMMODE, sizeof s1);
     else if (con_chan)
-      strncpyz(s1, MISC_STATMODE, sizeof s1);
+      strlcpy(s1, MISC_STATMODE, sizeof s1);
     else
-      strncpyz(s1, MISC_LOGMODE, sizeof s1);
+      strlcpy(s1, MISC_LOGMODE, sizeof s1);
   }
   cputime = getcputime();
   if (cputime < 0)
@@ -340,7 +340,7 @@ void tell_verbose_status(int idx)
   else {
     hr = cputime / 60;
     cputime -= hr * 60;
-    sprintf(s2, "CPU: %02d:%05.2f", (int) hr, cputime); /* Actally min/sec */
+    sprintf(s2, "CPU: %02d:%05.2f", (int) hr, cputime); /* Actually min/sec */
   }
   dprintf(idx, "%s %s (%s) - %s - %s: %4.1f%%\n", MISC_ONLINEFOR,
           s, s1, s2, MISC_CACHEHIT,
@@ -428,7 +428,7 @@ void reaffirm_owners()
     q = owner;
     p = strchr(q, ',');
     while (p) {
-      strncpyz(s, q, (p - q) + 1);
+      strlcpy(s, q, (p - q) + 1);
       rmspace(s);
       u = get_user_by_handle(userlist, s);
       if (u)
@@ -670,33 +670,17 @@ void list_timers(Tcl_Interp *irp, tcl_timer_t *stack)
   }
 }
 
-/* Oddly enough, written by Sup (former(?) Eggdrop coder)
- */
-int isowner(char *name)
-{
-  register char *ptr = NULL, *s = NULL, *n = NULL;
+int isowner(char *name) {
+  char s[sizeof owner];
+  char *sep = ", \t\n\v\f\r";
+  char *word;
 
-  if (!name)
-    return 0;
-
-  ptr = owner - 1;
-
-  do {
-    ptr++;
-    if (*ptr && !egg_isspace(*ptr) && *ptr != ',') {
-      if (!s)
-        s = ptr;
-    } else if (s) {
-      for (n = name; *n && *s && s < ptr &&
-           tolower((unsigned) *n) == tolower((unsigned) *s); n++, s++);
-
-      if (s == ptr && !*n)
-        return 1;
-
-      s = NULL;
+  strcpy(s, owner);
+  for (word = strtok(s, sep); word; word = strtok(NULL, sep)) {
+    if (!strcasecmp(name, word)) {
+      return 1;
     }
-  } while (*ptr);
-
+  }
   return 0;
 }
 
@@ -705,7 +689,7 @@ int isowner(char *name)
  */
 void add_hq_user()
 {
-  if (!backgrd && term_z > 0 && userlist) {
+  if (!backgrd && term_z >= 0) {
     /* HACK: Workaround using dcc[].nick not to pass literal "-HQ" as a non-const arg */
     dcc[term_z].user = get_user_by_handle(userlist, dcc[term_z].nick);
     /* Make sure there's an innocuous -HQ user if needed */
