@@ -1,10 +1,9 @@
 /*
- * inet_ntop.h --
- *
- *	prototypes for inet_ntop.c
+ * inet_ntop.h
+ *   prototypes for inet_ntop.c
  */
 /*
- * Copyright (C) 2000, 2001, 2002, 2003 Eggheads Development Team
+ * Copyright (C) 2010 - 2018 Eggheads Development Team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,22 +19,19 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
-/*
- * $Id: inet_ntop.h,v 1.1 2003/04/01 22:58:08 wcc Exp $
- */
 
 #ifndef _EGG_COMPAT_INET_NTOP_H
 #define _EGG_COMPAT_INET_NTOP_H
 
 #include "src/main.h"
-#include <sys/socket.h>
+
+#ifdef HAVE_SYS_SOCKET_H
+#  include <sys/socket.h>
+#endif
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
 #ifndef HAVE_INET_NTOP
-const char *egg_inet_ntop(int af, const void *src, char *dst, socklen_t size);
-#else
-#  define egg_inet_ntop inet_ntop
+const char *inet_ntop(int af, const void *src, char *dst, socklen_t size);
 #endif
-
-#endif /* !_EGG_COMPAT_INET_NTOP_H */
+#endif /* _EGG_COMPAT_INET_NTOP_H */
