@@ -32,18 +32,18 @@ typedef struct {
 } devent_type;
 
 typedef struct {
-  char *proc;                   /* Tcl proc                       */
-  char *paras;                  /* Additional parameters          */
+  char *proc;                   /* Tcl proc                        */
+  char *paras;                  /* Additional parameters           */
   sockname_t sockname;
 } devent_tclinfo_t;
 
 typedef struct devent_str {
-  struct devent_str *next;      /* Pointer to next dns_event      */
+  struct devent_str *next;      /* Pointer to next dns_event       */
   devent_type *type;
-  u_8bit_t lookup;              /* RES_IPBYHOST or RES_HOSTBYIP   */
+  uint8_t lookup;               /* RES_IPBYHOST or RES_HOSTBYIP    */
   union {
-    sockname_t *ip_addr;	/* Pointer to address placeholder */
-    char *hostname;             /* Hostname                       */
+    sockname_t *ip_addr;        /* Pointer to address placeholder  */
+    char *hostname;             /* Hostname                        */
   } res_data;
   void *other;                  /* Data specific to the event type */
 } devent_t;
