@@ -47,8 +47,9 @@
  *       You should leave this at 32 characters and modify nick-len in the
  *       configuration file instead.
  */
-#define HANDLEN 32   /* valid values 9->NICKMAX  */
-#define NICKMAX 32  /* valid values HANDLEN->32 */
+#define CHANNELLEN 80 /* FIXME see issue #3 and issue #38 and rfc1459 <= 200 */
+#define HANDLEN    32 /* valid values 9->NICKMAX                             */
+#define NICKMAX    32 /* valid values HANDLEN->32                            */
 
 
 /* Handy string lengths */
@@ -248,7 +249,7 @@
 
 
 /* Use high-order bits for getting the random integer. With a modern
- * random() implmentation, modulo would probably be sufficient, but on
+ * random() implementation, modulo would probably be sufficient, but on
  * systems lacking random(), it may just be a macro for an older rand()
  * function.
  */
@@ -268,10 +269,6 @@
 #  define sigemptyset(x) ((*(int *)(x))=0)
 #endif
 
-#ifndef HAVE_SOCKLEN_T
-typedef int socklen_t;
-#endif
-
 #ifdef TLS
 #  include <openssl/ssl.h>
 #endif
@@ -308,12 +305,8 @@ typedef int socklen_t;
 #  define free(x)   dont_use_old_free(x)
 #endif /* !COMPILING_MEM */
 
-typedef uint8_t u_8bit_t;
-typedef uint16_t u_16bit_t;
-typedef uint32_t u_32bit_t;
-
 /* IP type */
-typedef u_32bit_t IP;
+typedef uint32_t IP;
 
 /* Debug logging macros */
 #define debug0(x)             putlog(LOG_DEBUG,"*",x)
@@ -329,6 +322,12 @@ typedef u_32bit_t IP;
 #define egg_isspace(x)  isspace((int)  (unsigned char) (x))
 #define egg_islower(x)  islower((int)  (unsigned char) (x))
 
+/* The following 3 functions are for backward compatibility only */
+#define egg_bzero(dest, len) memset(dest, 0, len)
+#define egg_memcpy(dst, src, len) memcpy(dst, src, len)
+#define egg_memset(dest, c, len) memset(dest, c, len)
+#define my_memcpy(dst, src, len) memcpy(dst, src, len)
+
 /***********************************************************************/
 
 /* It's used in so many places, let's put it here */
@@ -391,7 +390,7 @@ struct dcc_t {
   char host[UHOSTLEN];
   struct dcc_table *type;
   time_t timeval;               /* This is used for timeout checking. */
-  unsigned long status;         /* A LOT of dcc types have status things; makes it more availabe. */
+  unsigned long status;         /* A LOT of dcc types have status things; makes it more available. */
   union {
     struct chat_info *chat;
     struct file_info *file;
@@ -408,17 +407,17 @@ struct dcc_t {
 };
 
 struct chat_info {
-  char *away;                   /* non-NULL if user is away             */
-  int msgs_per_sec;             /* used to stop flooding                */
-  int con_flags;                /* with console: what to show           */
-  int strip_flags;              /* what codes to strip (b,r,u,c,a,g,*)  */
-  char con_chan[81];            /* with console: what channel to view   */
-  int channel;                  /* 0=party line, -1=off                 */
-  struct msgq *buffer;          /* a buffer of outgoing lines
-                                 * (for .page cmd)                      */
-  int max_line;                 /* maximum lines at once                */
-  int line_count;               /* number of lines sent since last page */
-  int current_lines;            /* number of lines total stored         */
+  char *away;                    /* non-NULL if user is away             */
+  int msgs_per_sec;              /* used to stop flooding                */
+  int con_flags;                 /* with console: what to show           */
+  int strip_flags;               /* what codes to strip (b,r,u,c,a,g,*)  */
+  char con_chan[CHANNELLEN + 1]; /* with console: what channel to view   */
+  int channel;                   /* 0=party line, -1=off                 */
+  struct msgq *buffer;           /* a buffer of outgoing lines
+                                  * (for .page cmd)                      */
+  int max_line;                  /* maximum lines at once                */
+  int line_count;                /* number of lines sent since last page */
+  int current_lines;             /* number of lines total stored         */
   char *su_nick;
 };
 
@@ -467,6 +466,9 @@ struct bot_info {
   char linker[NOTENAMELEN + 1]; /* who requested this link              */
   int numver;
   int port;                     /* base port                            */
+#ifdef TLS
+  int ssl;                      /* base ssl                             */
+#endif
   int uff_flags;                /* user file feature flags              */
 };
 
@@ -653,6 +655,10 @@ typedef struct {
 #define SOCK_VIRTUAL    0x0200  /* not-connected socket (dont read it!) */
 #define SOCK_BUFFER     0x0400  /* buffer data; don't notify dcc funcs  */
 #define SOCK_TCL        0x0800  /* tcl socket, don't do anything on it  */
+#ifdef TLS
+#  define SOCK_SENTTLS  0x1000  /* Socket that awaits a starttls in the
+                                 * next read                            */
+#endif
 
 /* Flags to sock_has_data
  */
@@ -709,10 +715,10 @@ enum {
 
 /* Context information to attach to SSL sockets */
 typedef struct {
-  int flags;			/* listen/connect, generic ssl flags      */
-  int verify;			/* certificate validation mode            */
-  int loglevel;			/* log level to output TLS information to */
-  char host[256];		/* host or IP for certificate validation  */
+  int flags;                    /* listen/connect, generic ssl flags      */
+  int verify;                   /* certificate validation mode            */
+  int loglevel;                 /* log level to output TLS information to */
+  char host[256];               /* host or IP for certificate validation  */
   IntFunc cb;
 } ssl_appdata;
 #endif /* TLS */
@@ -750,6 +756,13 @@ enum {
   EGG_OPTION_UNSET = 2          /* Unset option(s).             */
 };
 
+#define ESC             27      /* Oct              033
+                                 * Hex              1B
+                                 * Caret notation   ^[
+                                 * Escape sequences \e
+                                 * \e is not supported in all compilers
+                                 */
+
 /* Telnet codes.  See "TELNET Protocol Specification" (RFC 854) and
  * "TELNET Echo Option" (RFC 875) for details. */
 
