@@ -124,7 +124,7 @@ static void add_assoc(char *name, int chan)
       return;
     }
     if (a->channel == chan) {
-      strncpyz(a->name, name, sizeof a->name);
+      strlcpy(a->name, name, sizeof a->name);
       return;
     }
   }
@@ -134,7 +134,7 @@ static void add_assoc(char *name, int chan)
       b = nmalloc(sizeof *b);
       b->next = a;
       b->channel = chan;
-      strncpyz(b->name, name, sizeof b->name);
+      strlcpy(b->name, name, sizeof b->name);
       if (old == NULL)
         assoc = b;
       else
@@ -146,7 +146,7 @@ static void add_assoc(char *name, int chan)
   b = nmalloc(sizeof *b);
   b->next = NULL;
   b->channel = chan;
-  strncpyz(b->name, name, sizeof b->name);
+  strlcpy(b->name, name, sizeof b->name);
   if (old == NULL)
     assoc = b;
   else
@@ -295,8 +295,7 @@ static int tcl_assoc STDVAR
     return TCL_ERROR;
   }
   if (argc == 3) {
-    strncpy(name, argv[2], 20);
-    name[20] = 0;
+    strlcpy(name, argv[2], sizeof name);
     add_assoc(name, chan);
     botnet_send_assoc(-1, chan, "*script*", name);
   }
@@ -334,7 +333,6 @@ static void zapf_assoc(char *botnick, char *code, char *par)
         chanout_but(-1, chan, ASSOC_CHNAME_REM, botnick, nick);
       } else if (get_assoc(par) != chan) {
         /* New one i didn't know about -- pass it on */
-        s1 = get_assoc_name(chan);
         add_assoc(par, chan);
         chanout_but(-1, chan, ASSOC_CHNAME_NAMED2, botnick, nick, par);
       }
