@@ -132,8 +132,7 @@ static int ctcp_TIME(char *nick, char *uhost, char *handle, char *object,
 
   if (ctcp_mode == 1)
     return 1;
-  strncpy(tms, ctime(&now), 24);
-  tms[24] = 0;
+  strlcpy(tms, ctime(&now), sizeof tms);
   simple_sprintf(ctcp_reply, "%s\001TIME %s\001", ctcp_reply, tms);
   return 1;
 }
@@ -157,7 +156,7 @@ static int ctcp_CHAT(char *nick, char *uhost, char *handle, char *object,
       return 1;
     }
 
-// * Check if SSL, IPv4, or IPv6 were requested
+/* Check if SSL, IPv4, or IPv6 were requested */
     if (
 #ifdef IPV6
     (!egg_strcasecmp(keyword, "CHAT6")) ||
@@ -191,8 +190,8 @@ static int ctcp_CHAT(char *nick, char *uhost, char *handle, char *object,
          * CTCP replies are NOTICE's this has to be a PRIVMSG
          * -poptix 5/1/1997 */
 #ifdef TLS
-	  dprintf(DP_SERVER, "PRIVMSG %s :\001DCC %sCHAT chat %s %u\001\n",
-		  nick, (ssl ? "S" : ""), s, dcc[i].port);
+          dprintf(DP_SERVER, "PRIVMSG %s :\001DCC %sCHAT chat %s %u\001\n",
+                  nick, (ssl ? "S" : ""), s, dcc[i].port);
 #else
           dprintf(DP_SERVER, "PRIVMSG %s :\001DCC CHAT chat %s %u\001\n",
                   nick, s, dcc[i].port);
@@ -202,7 +201,7 @@ static int ctcp_CHAT(char *nick, char *uhost, char *handle, char *object,
     }
 #ifdef TLS
     simple_sprintf(ctcp_reply, "%s\001ERROR no %stelnet port\001", ctcp_reply,
-	 	   (ssl ? "SSL enabled " : ""));
+                   (ssl ? "SSL enabled " : ""));
 #else
     simple_sprintf(ctcp_reply, "%s\001ERROR no telnet port\001", ctcp_reply);
 #endif
@@ -282,17 +281,11 @@ char *ctcp_start(Function *global_funcs)
   add_tcl_ints(myints);
   add_builtins(H_ctcp, myctcp);
   add_help_reference("ctcp.help");
-  if (!ctcp_version[0]) {
-    strncpy(ctcp_version, ver, 120);
-    ctcp_version[120] = 0;
-  }
-  if (!ctcp_finger[0]) {
-    strncpy(ctcp_finger, ver, 120);
-    ctcp_finger[120] = 0;
-  }
-  if (!ctcp_userinfo[0]) {
-    strncpy(ctcp_userinfo, ver, 120);
-    ctcp_userinfo[120] = 0;
-  }
+  if (!ctcp_version[0])
+    strlcpy(ctcp_version, ver, sizeof ctcp_version);
+  if (!ctcp_finger[0])
+    strlcpy(ctcp_finger, ver, sizeof ctcp_finger);
+  if (!ctcp_userinfo[0])
+    strlcpy(ctcp_userinfo, ver, sizeof ctcp_userinfo);
   return NULL;
 }
