@@ -126,32 +126,32 @@ static const char *classtypes[CLASSTYPES_COUNT + 1] = {
 #endif /* DEBUG_DNS */
 
 typedef struct {
-  u_16bit_t id;                 /* Packet id */
-  u_8bit_t databyte_a;
+  uint16_t id;                 /* Packet id */
+  uint8_t databyte_a;
   /* rd:1                             recursion desired
    * tc:1                             truncated message
-   * aa:1                             authoritive answer
+   * aa:1                             authoritative answer
    * opcode:4                         purpose of message
    * qr:1                             response flag
    */
-  u_8bit_t databyte_b;
+  uint8_t databyte_b;
   /* rcode:4                          response code
    * unassigned:2                     unassigned bits
    * pr:1                             primary server required (non standard)
    * ra:1                             recursion available
    */
-  u_16bit_t qdcount;            /* Query record count */
-  u_16bit_t ancount;            /* Answer record count */
-  u_16bit_t nscount;            /* Authority reference record count */
-  u_16bit_t arcount;            /* Resource reference record count */
+  uint16_t qdcount;            /* Query record count */
+  uint16_t ancount;            /* Answer record count */
+  uint16_t nscount;            /* Authority reference record count */
+  uint16_t arcount;            /* Resource reference record count */
 } packetheader;
 
 typedef struct {
-  u_16bit_t datatype;
-  u_16bit_t class;
-  u_32bit_t ttl;
-  u_16bit_t datalength;
-  u_8bit_t data[];
+  uint16_t datatype;
+  uint16_t class;
+  uint32_t ttl;
+  uint16_t datalength;
+  uint8_t data[FLEXIBLE_ARRAY_MEMBER];
 } res_record;
 
 #ifndef HFIXEDSZ
@@ -170,14 +170,14 @@ typedef struct {
 #define getheader_pr(x) ((x->databyte_b >> 6) & 1)
 #define getheader_ra(x) (x->databyte_b >> 7)
 
-#define sucknetword(x)  ((x)+=2,((u_16bit_t)  (((x)[-2] <<  8) | ((x)[-1] <<  0))))
+#define sucknetword(x)  ((x)+=2,((uint16_t)  (((x)[-2] <<  8) | ((x)[-1] <<  0))))
 #define sucknetshort(x) ((x)+=2,((short) (((x)[-2] <<  8) | ((x)[-1] <<  0))))
 #define sucknetdword(x) ((x)+=4,((dword) (((x)[-4] << 24) | ((x)[-3] << 16) | \
                                           ((x)[-2] <<  8) | ((x)[-1] <<  0))))
 #define sucknetlong(x)  ((x)+=4,((long)  (((x)[-4] << 24) | ((x)[-3] << 16) | \
                                           ((x)[-2] <<  8) | ((x)[-1] <<  0))))
 
-static u_32bit_t resrecvbuf[(MAX_PACKETSIZE + 7) >> 2]; /* MUST BE DWORD ALIGNED */
+static uint32_t resrecvbuf[(MAX_PACKETSIZE + 7) >> 2]; /* MUST BE DWORD ALIGNED */
 
 static struct resolve *idbash[BASH_SIZE];
 static struct resolve *ipbash[BASH_SIZE];
@@ -214,8 +214,8 @@ static const char nullstring[] = "";
  */
 static char *strtdiff(char *d, long signeddiff)
 {
-  u_32bit_t diff;
-  u_32bit_t seconds, minutes, hours;
+  uint32_t diff;
+  uint32_t seconds, minutes, hours;
   long day;
 
   if ((diff = labs(signeddiff))) {
@@ -258,23 +258,23 @@ static struct resolve *allocresolve()
 
 /* Return the hash bucket number for id.
  */
-static inline u_32bit_t getidbash(u_16bit_t id)
+static uint32_t getidbash(uint16_t id)
 {
-  return (u_32bit_t) BASH_MODULO(id);
+  return (uint32_t) BASH_MODULO(id);
 }
 
 /* Return the hash bucket number for ip.
  */
-static inline u_32bit_t getipbash(IP ip)
+static uint32_t getipbash(IP ip)
 {
-  return (u_32bit_t) BASH_MODULO(ip);
+  return (uint32_t) BASH_MODULO(ip);
 }
 
 #ifdef IPV6
 static unsigned long getip6bash(struct in6_addr *ip6) {
-  u_32bit_t x, y;
-  egg_memcpy(&x, ip6->s6_addr     , sizeof x);
-  egg_memcpy(&y, ip6->s6_addr + 12, sizeof y);
+  uint32_t x, y;
+  memcpy(&x, ip6->s6_addr     , sizeof x);
+  memcpy(&y, ip6->s6_addr + 12, sizeof y);
   x ^= y;
   return (unsigned long) BASH_MODULO(x);
 }
@@ -282,9 +282,9 @@ static unsigned long getip6bash(struct in6_addr *ip6) {
 
 /* Return the hash bucket number for host.
  */
-static u_32bit_t gethostbash(char *host)
+static uint32_t gethostbash(char *host)
 {
-  u_32bit_t bashvalue = 0;
+  uint32_t bashvalue = 0;
 
   for (; *host; host++) {
     bashvalue ^= *host;
@@ -298,7 +298,7 @@ static u_32bit_t gethostbash(char *host)
 static void linkresolveid(struct resolve *addrp)
 {
   struct resolve *rp;
-  u_32bit_t bashnum;
+  uint32_t bashnum;
 
   bashnum = getidbash(addrp->id);
   rp = idbash[bashnum];
@@ -330,7 +330,7 @@ static void linkresolveid(struct resolve *addrp)
  */
 static void unlinkresolveid(struct resolve *rp)
 {
-  u_32bit_t bashnum;
+  uint32_t bashnum;
 
   bashnum = getidbash(rp->id);
   if (idbash[bashnum] == rp) {
@@ -350,7 +350,7 @@ static void unlinkresolveid(struct resolve *rp)
 static void linkresolvehost(struct resolve *addrp)
 {
   struct resolve *rp;
-  u_32bit_t bashnum;
+  uint32_t bashnum;
   int ret;
 
   bashnum = gethostbash(addrp->hostn);
@@ -386,7 +386,7 @@ static void linkresolvehost(struct resolve *addrp)
  */
 static void unlinkresolvehost(struct resolve *rp)
 {
-  u_32bit_t bashnum;
+  uint32_t bashnum;
 
   bashnum = gethostbash(rp->hostn);
   if (hostbash[bashnum] == rp) {
@@ -407,7 +407,7 @@ static void unlinkresolvehost(struct resolve *rp)
 static void linkresolveip(struct resolve *addrp)
 {
   struct resolve *rp;
-  u_32bit_t bashnum;
+  uint32_t bashnum;
 
   bashnum = getipbash(addrp->ip);
   rp = ipbash[bashnum];
@@ -471,7 +471,7 @@ static void linkresolveip6(struct resolve *addrp){
 
 static void unlinkresolveip6(struct resolve *rp)
 {
-  u_32bit_t bashnum;
+  uint32_t bashnum;
 
   bashnum = getip6bash(&rp->sockname.addr.s6.sin6_addr);
   if (ip6bash[bashnum] == rp) {
@@ -491,7 +491,7 @@ static void unlinkresolveip6(struct resolve *rp)
  */
 static void unlinkresolveip(struct resolve *rp)
 {
-  u_32bit_t bashnum;
+  uint32_t bashnum;
 
   bashnum = getipbash(rp->ip);
   if (ipbash[bashnum] == rp) {
@@ -537,7 +537,7 @@ static void linkresolve(struct resolve *rp)
   }
 }
 
-/* Remove reqeust structure rp from the expireresolves list.
+/* Remove request structure rp from the expireresolves list.
  */
 static void untieresolve(struct resolve *rp)
 {
@@ -571,7 +571,7 @@ static void unlinkresolve(struct resolve *rp)
 
 /* Find request structure using the id.
  */
-static struct resolve *findid(u_16bit_t id)
+static struct resolve *findid(uint16_t id)
 {
   struct resolve *rp;
   int bashnum;
@@ -646,7 +646,7 @@ static struct resolve *findip6(struct in6_addr *ip6)
 static struct resolve *findip(IP ip)
 {
   struct resolve *rp;
-  u_32bit_t bashnum;
+  uint32_t bashnum;
   bashnum = getipbash(ip);
   rp = ipbash[bashnum];
   if (rp) {
@@ -666,10 +666,10 @@ static struct resolve *findip(IP ip)
 void ptrstring4(IP *ip, char *buf, size_t sz)
 {
   egg_snprintf(buf, sz, "%u.%u.%u.%u.in-addr.arpa",
-           ((u_8bit_t *) ip)[3],
-           ((u_8bit_t *) ip)[2],
-           ((u_8bit_t *) ip)[1],
-           ((u_8bit_t *) ip)[0]);
+           ((uint8_t *) ip)[3],
+           ((uint8_t *) ip)[2],
+           ((uint8_t *) ip)[1],
+           ((uint8_t *) ip)[0]);
 }
 
 #ifdef IPV6
@@ -711,16 +711,16 @@ void ptrstring(struct sockaddr *addr, char *buf, size_t sz)
 
 /* Create packet for the request and send it to all available nameservers.
  */
-static void dorequest(char *s, int type, u_16bit_t id)
+static void dorequest(char *s, int type, uint16_t id)
 {
   packetheader *hp;
   int r, i;
-  u_8bit_t *buf;
+  uint8_t *buf;
 
   /* Use malloc here instead of a static buffer, as per res_mkquery()'s manual
    * buf should be aligned on an eight byte boundary. malloc() should return a
    * pointer to an address properly aligned for any data type. Failing to
-   * provide a aligned buffer will result in a SIGBUS crash atleast on SPARC
+   * provide a aligned buffer will result in a SIGBUS crash at least on SPARC
    * CPUs.
    */
   buf = nmalloc(MAX_PACKETSIZE + 1);
@@ -771,7 +771,7 @@ static void sendrequest(struct resolve *rp, int type)
     idseed = (((idseed + idseed) | (long) time(NULL))
               + idseed - 0x54bad4a) ^ aseed;
     aseed ^= idseed;
-    rp->id = (u_16bit_t) idseed;
+    rp->id = (uint16_t) idseed;
   } while (findid(rp->id));
   linkresolveid(rp);            /* Add id to id hash table */
   resendrequest(rp, type);      /* Send request */
@@ -817,7 +817,7 @@ static void passrp(struct resolve *rp, long ttl, int type)
 
 /* Parses the response packets received.
  */
-void parserespacket(u_8bit_t *response, int len)
+void parserespacket(uint8_t *response, int len)
 {
 #ifdef IPV6
   int ready = 0;
@@ -826,8 +826,8 @@ void parserespacket(u_8bit_t *response, int len)
   res_record *rr;
   packetheader *hdr;
   struct resolve *rp;
-  u_8bit_t rc, *c = response;
-  u_16bit_t qdatatype, qclass;
+  uint8_t rc, *c = response;
+  uint16_t qdatatype, qclass;
   if (len < sizeof(packetheader)) {
     debug1(RES_ERR "Packet smaller than standard header size: %d bytes.", len);
     return;
@@ -972,7 +972,7 @@ void parserespacket(u_8bit_t *response, int len)
       return;
     }
     c += 10 + rr->datalength;
-    if (0 > response + len) {
+    if (c > response + len) {
       ddebug0(RES_ERR "Specified rdata length exceeds packet size.");
       return;
     }
@@ -998,7 +998,7 @@ void parserespacket(u_8bit_t *response, int len)
         rp->ttl = rr->ttl;
         rp->sockname.addrlen = sizeof(struct sockaddr_in);
         rp->sockname.addr.sa.sa_family = AF_INET;
-        egg_memcpy(&rp->sockname.addr.s4.sin_addr, rr->data, 4);
+        memcpy(&rp->sockname.addr.s4.sin_addr, rr->data, 4);
 #ifndef IPV6
         passrp(rp, rr->ttl, T_A);
         return;
@@ -1017,7 +1017,7 @@ void parserespacket(u_8bit_t *response, int len)
         rp->ttl = rr->ttl;
         rp->sockname.addrlen = sizeof(struct sockaddr_in6);
         rp->sockname.addr.sa.sa_family = AF_INET6;
-        egg_memcpy(&rp->sockname.addr.s6.sin6_addr, rr->data, 16);
+        memcpy(&rp->sockname.addr.s6.sin6_addr, rr->data, 16);
         if (ready || pref_af) {
           passrp(rp, rr->ttl, T_A);
           return;
@@ -1053,7 +1053,7 @@ void parserespacket(u_8bit_t *response, int len)
           return;
         }
         ddebug1(RES_MSG "answered domain is CNAME for: %s", namestring);
-        strncpy(stackstring, namestring, 1024);
+        strlcpy(stackstring, namestring, sizeof stackstring);
         break;
       default:
         ddebug2(RES_ERR "Received unimplemented data type: %u (%s)",
@@ -1084,7 +1084,7 @@ static void dns_ack(void)
   socklen_t fromlen = sizeof(struct sockaddr_in);
   int r, i;
 
-  r = recvfrom(resfd, (u_8bit_t *) resrecvbuf, MAX_PACKETSIZE, 0,
+  r = recvfrom(resfd, (uint8_t *) resrecvbuf, MAX_PACKETSIZE, 0,
                (struct sockaddr *) &from, &fromlen);
   if (r <= 0) {
     ddebug1(RES_MSG "Socket error: %s", strerror(errno));
@@ -1106,7 +1106,7 @@ static void dns_ack(void)
     ddebug1(RES_ERR "Received reply from unknown source: %s",
                 iptostr((struct sockaddr *) &from));
   else
-    parserespacket((u_8bit_t *) resrecvbuf, r);
+    parserespacket((uint8_t *) resrecvbuf, r);
 }
 
 /* Remove or resend expired requests. Called once a second.
@@ -1184,7 +1184,7 @@ static void dns_lookup(sockname_t *addr)
   rp->state = STATE_PTRREQ;
   rp->sends = 1;
   rp->type = T_PTR;
-  egg_memcpy(&rp->sockname, addr, sizeof(sockname_t));
+  memcpy(&rp->sockname, addr, sizeof(sockname_t));
   if (addr->family == AF_INET) {
     rp->ip = addr->addr.s4.sin_addr.s_addr;
     linkresolveip(rp);
@@ -1274,6 +1274,13 @@ static int init_dns_core(void)
 
   /* Initialise the resolv library. */
   res_init();
+  #ifdef NETBSD_HACKS
+    puts("netbsd found. if eggdrop crashes with\n"
+         "  _res is not supported for multi-threaded programs.\n"
+         "  [1]   Abort trap (core dumped) ./eggdrop -nt\n"
+         "dns.mod must be disabled by commenting out in eggdrop.conf\n"
+         "  #loadmodule dns");
+  #endif
   _res.options |= RES_RECURSE | RES_DEFNAMES | RES_DNSRCH;
   for (i = 0; i < _res.nscount; i++)
     _res.nsaddr_list[i].sin_family = AF_INET;
@@ -1282,7 +1289,7 @@ static int init_dns_core(void)
     return 0;
 
   /* Initialise the hash tables. */
-  aseed = time(NULL) ^ (time(NULL) << 3) ^ (u_32bit_t) getpid();
+  aseed = time(NULL) ^ (time(NULL) << 3) ^ (uint32_t) getpid();
   for (i = 0; i < BASH_SIZE; i++) {
     idbash[i] = NULL;
     ipbash[i] = NULL;
