@@ -59,7 +59,7 @@ static int tcl_putnow STDVAR
     if ((p - r) > (sizeof(buf) - 2 - (q - buf)))
       break; /* That's all folks, no space left */
     len = p - r + 1; /* leave space for '\0' */
-    strncpyz(q, r, len);
+    strlcpy(q, r, len);
     if (check_tcl_out(0, q, 0)) {
       if (!*p || ((argc == 3) && !egg_strcasecmp(argv[2], "-oneline")))
         break;
@@ -94,9 +94,8 @@ static int tcl_putquick STDVAR
                      "-normal -next", NULL);
     return TCL_ERROR;
   }
-  strncpy(s, argv[1], 510);
+  strlcpy(s, argv[1], sizeof s);
 
-  s[510] = 0;
   p = strchr(s, '\n');
   if (p != NULL)
     *p = 0;
@@ -122,9 +121,8 @@ static int tcl_putserv STDVAR
                      "-normal -next", NULL);
     return TCL_ERROR;
   }
-  strncpy(s, argv[1], 510);
+  strlcpy(s, argv[1], sizeof s);
 
-  s[510] = 0;
   p = strchr(s, '\n');
   if (p != NULL)
     *p = 0;
@@ -150,9 +148,8 @@ static int tcl_puthelp STDVAR
                      "-normal -next", NULL);
     return TCL_ERROR;
   }
-  strncpy(s, argv[1], 510);
+  strlcpy(s, argv[1], sizeof s);
 
-  s[510] = 0;
   p = strchr(s, '\n');
   if (p != NULL)
     *p = 0;
@@ -171,7 +168,7 @@ static int tcl_jump STDVAR
   BADARGS(1, 4, " ?server? ?port? ?pass?");
 
   if (argc >= 2) {
-    strncpyz(newserver, argv[1], sizeof newserver);
+    strlcpy(newserver, argv[1], sizeof newserver);
     if (argc >= 3)
 #ifdef TLS
     {
@@ -187,7 +184,7 @@ static int tcl_jump STDVAR
     else
       newserverport = default_port;
     if (argc == 4)
-      strncpyz(newserverpass, argv[3], sizeof newserverpass);
+      strlcpy(newserverpass, argv[3], sizeof newserverpass);
   }
   cycle_time = 0;
 
